capture log close
log using rm3ch4-interp, replace text

//  Ch 4: Interpretation | rm3ch4-interp.do 2014-08-05
//  Regression Models for Categorical Outcomes using Stata, 3rd edition
//  Scott Long & Jeremy Freese

version 13.1
clear all
macro drop _all
program drop _all
set linesize 80
set scheme s2manual

// 4.3 Predictions for each observation

use binlfp4, clear
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
predict prob
summarize prob

//  4.4 Predictions at specified values

* using margins for predictions

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
margins
margins, atmeans
margins, at(k5=1 k618=1 agecat=1 wc=0 hc=0 lwg=1 inc=20)
margins, at(k5=1 k618=1 agecat=1 wc=0 hc=0) atmeans
margins, at(k5=1 k618=1 agecat=1 wc=0 hc=0 lwg=1.097 inc=20.13)
margins, at(k5=1 k618=1 agecat=1 wc=0 hc=0 (mean) lwg inc)
margins, at(k5=1 k618=1 agecat=1 wc=0 hc=0 (mean) lwg (median) inc)
margins, at(k5=1 k618=1 agecat=1 wc=0 hc=0 lwg=1.097)
margins, at(k5=1 k618=1 agecat=1 wc=0 hc=0 lwg=1.097 (asobserved) inc)

* asobserved using replace

margins, at(k5=1 k618=1 agecat=1 wc=0 hc=0 lwg=1)
replace k5 = 1
replace k618 = 1
replace agecat = 1
replace wc = 0
replace hc = 0
replace lwg = 1

capture drop prob
predict prob
label var prob "predict with fixing values of all but inc"
sum prob

* making multiple predictions

use binlfp4, clear
logit lfp k5 k618 age i.wc i.hc lwg inc, nolog
margins, at(wc=0 wc=1) atmeans
margins, at(wc=0) at(wc=1) atmeans
margins, at(wc=(0 1)) atmeans
margins, at(age=(30(10)60)) atmeans
margins, at(age=(30(10)60) wc=(0 1)) atmeans
margins, at(age=(30(10)60) wc=(0 1)) atmeans noatlegend
mlistat
margins, at(wc=0 age=(30(10)60)) at(wc=1 age=(30(10)60)) atmeans noatlegend
mlistat, noconstant

* predictions for groups defined by levels of categorical variables

logit lfp k5 age i.wc i.hc, nolog
margins, at(wc=(0 1)) atmeans
margins wc, atmeans
margins, over(wc) atmeans
margins if wc==0, atmeans
margins if wc==1, atmeans

* (advanced) non-default predictions using margins

use gssclass4, clear
ologit class i.fem i.white i.year i.ed age inc, nolog
margins, predict(outcome(2))
margins, expression(1-predict(outcome(1)))
margins, expression( predict(outcome(1)) - predict(outcome(#4)) )

use binlfp4, clear
logit lfp k5 k618 age i.wc i.hc lwg inc, nolog
margins, expression(1-predict(pr))
margins, predict(pr)
margins
margins, expression(predict(pr)-.5)

* tables of predictions using mtable

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
mtable, at(wc=(0 1) hc=(0 1)) atmeans
margins, at(wc=(0 1) hc=(0 1)) atmeans

mtable, at(wc=(0 1) hc=(0 1)) atmeans estname(Pr_LFP) ///
  statistics(ci)
mtable, at(k5=0 k618=0 wc=(0 1)) atmeans atvars(k5 k618 wc) brief

* atvars with mtable

mtable, at(k5=0 k618=0 wc=(0 1)) atmeans atvars(k5 k618 wc) brief
mtable, at(wc=(0 1) hc=(0 1)) atmeans estname(Pr_LFP) atvars(_none)

* categorical and count outcomes

use gssclass4, replace
ologit class i.fem i.white i.year i.ed age inc, nolog
mtable, at(fem=(0 1) white=(0 1)) atmeans stat(ci) dec(2)
mtable, at(fem=(0 1) white=(0 1)) atmeans stat(ci) dec(2) long
mtable, at(fem=(0 1) white=(0 1)) outcome(1 4) atmeans brief

* (advanced) combining and formatting tables using mtable

use binlfp4, clear
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
mtable, at(k5=(0 1 2 3)) coleqnm(1st)
mtable, at(k5=(0 1 2 3)) atmeans right brief coleqnm(2nd)
mtable, at(k5=(0 1 2 3)) coleqnm(1st) clear
mtable, at(k5=(0 1 2 3)) atmeans right coleqnm(2nd)
quietly mtable, at(k5=(0 1 2 3)) estname(asobserved)
mtable, at(k5=(0 1 2 3)) atmeans atvars(_none) estname(atmeans) right brief

quietly mtable, at(k5=(0 1 2 3)) estname(asobserved)
mtable, at(k5=(0 1 2 3)) atmeans atvars(_none) estname(atmeans) ///
    title(Predicted probability of labor force participation) ///
    right brief norownum

//  4.5 Marginal effects: changes in predictions

* marginal effects using margins

use binlfp4, clear
logit lfp k5 i.agecat i.wc inc, nolog
margins, dydx(*)

* marginal effects using mtable

quietly mtable, at(wc=1) rowname(wc=1) statistics(ci) estname(Pr_LFP)
mtable, at(wc=0) rowname(wc=0) statistics(ci) estname(Pr_LFP) below
mtable, dydx(wc) rowname(wc=1 - wc=0) statistics(ci) estname(Pr_LFP) ///
  below brief

* posting predictions and using mlincom

use binlfp4, clear
logit lfp k5 i.agecat i.wc inc, nolog
estimates store model1
mtable, at(wc=(1 0)) post
matlist e(b)
lincom _b[1._at] - _b[2._at]
mlincom 1 - 2
mlincom 1 - 2, statistics(est pvalue)
mlincom 1 - 2, statistics(all)
estimates restore model1

* marginal effects using mchange

use binlfp4, clear
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
mchange
mchange inc, amount(range) trim(25)
mchange inc, amount(sd) delta(5)
mchange inc, amount(all) statistics(all)
mchange wc, statistics(start end est pvalue)

//  4.6 Plotting predictions

* plotting predictions with marginsplot

use binlfp4, clear
logit lfp k5 k618 age i.wc i.hc lwg inc, nolog
margins, at(age=(20(10)80) wc=(0 1)) atmeans
marginsplot
graph export rm3ch4-marginsplot-intro.emf, replace

qui margins, at(age=(20(10)80) wc=(0 1)) atmeans
marginsplot, plotdim(wc, label("No College" "College"))
graph export rm3ch4-marginsplot-bywc.emf, replace

marginsplot, recast(line) plotopts(lwidth(medthick)) ///
    plot1opt(lcolor(green)) plot2opt(lcolor(blue))
graph export rm3ch4-marginsplot-line.emf, replace

qui margins, at(age=(20(10)80) wc=(0 1)) atmeans
marginsplot, recastci(rarea) ciopts(lcolor(gs11) fcolor(gs13))
graph export rm3ch4-marginsplot-rarea.emf, replace

* plotting predictions using mgen

use binlfp4, clear
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
mgen, at(inc=(0(10)100)) stub(A) atmeans
list Apr Ainc in 1/12, clean
graph twoway connected Apr Ainc
graph export rm3ch4-mgen-twoway.emf, replace

quietly mgen, at(inc=(0(10)100) agecat=1) atmeans stub(A30) predlabel(Age 30-39)
quietly mgen, at(inc=(0(10)100) agecat=2) atmeans stub(A40) predlabel(40-49)
quietly mgen, at(inc=(0(10)100) agecat=3) atmeans stub(A50) predlabel(50+)
graph twoway connected A30pr A40pr A50pr A50inc, ytitle("Pr(In Labor Force)") ///
  xtitle("Income") legend(cols(3))
graph export rm3ch4-mgen-multilevel.emf, replace

use gssclass4, clear
ologit class i.fem i.white i.year i.ed age inc, nolog
mgen, at(age=(20(10)80)) stub(B) atmeans
list Bage Bpr1 Bpr2 Bpr3 Bpr4 in 1/8, clean
twoway line Bpr1 Bpr2 Bpr3 Bpr4 Bage
graph export rm3ch4-mgen-ologit.emf, replace

//  4.7 Interpretation of parameters

use science4, clear
regress job i.female i.phdclass mentcit3yr fellow pub1 cit1
listcoef, help
listcoef female phdclass pub1

use binlfp4, clear
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
listcoef, help
listcoef, percent help

log close
exit
